--[[
Drathals HUD2  - DHUD2
Copyright (c) 2006 by Markus Inger, 2006 by Caeryn Dryad, 2007-2008 by Horacio Hoyos

This file is part of DHUD2.

    DHUD2 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DHUD2 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DHUD2.  If not, see <http://www.gnu.org/licenses/>.
]]
--Auras
local math_ceil = math.ceil
local string_match = string.match
local _G = _G
local auraUpdateInterval = 1
local formatTime
do
    --[[
            formatTime: transform time in seconds to days/hours/minutes
            arguments:
                secs: time in seconds
            returns:
                formtated time  --]]
    function formatTime(secs)
        if secs >= 86400 then
            return format('%dd', math.ceil(secs/86400))
        elseif secs >= 3600 then
            return format('%dh', math.ceil(secs/3600))
        elseif secs >= 60 then
            return format('%dm', math.ceil(secs/60))
        else
            return format("%d", secs)
        end
    end
end

function DHUD2:updateButtons(texture, count, side, show)
	--DHUD2:Debug("updateCombos", texture, count, side, show)
    for i = 1, 5 do
        local button = _G["DHUD2_"..side.."b"..i]
        if i <= count and show then
			DHUD2:Debug("updateCombos", i, "Interface\\AddOns\\DHUD2\\textures\\"..texture..i)
            button:SetNormalTexture("Interface\\AddOns\\DHUD2\\textures\\"..texture..i)
            button:Show()
        else
            button:Hide()
        end
    end
end

    
function DHUD2:updatePlayerPvP(show, side)
    if show then
        local _, _, _, _, _, _, _, x0, x1, y0, y1, path = unpack(self.layout.icons.target)
        if UnitIsPVPFreeForAll("player")  then
            path = path[3]
        elseif UnitIsPVP("player") then 
            local faction = UnitFactionGroup("player")
            if faction == "Horde" then
                path = path[2]
            else
                path = path[1]
            end
        else
            _G["DHUD2_"..side.."pvp"]:Hide()
            return
        end
        local texture = _G["DHUD2_"..side.."pvp_Texture"]
        texture:SetTexture(path)
        texture:SetTexCoord(x0,x1,y0,y1)
        _G["DHUD2_"..side.."pvp"]:Show()
    else
        _G["DHUD2_"..side.."pvp"]:Hide()
    end
end

function DHUD2:updatePlayerAuras(show, filter, side)
	DHUD2:Debug("updatePlayerAuras", show, filter, side)
    -- Auras can be buffs or Weapon Enchants
    self:CancelAllTimers()
    local i, icon
    local j = 1
    local p = DHUD2.db.profile
    local timeToEvent = 0
	local timeFilter = (p.pBuffsExpMin * 60) + p.pBuffsExpSec
	
    if show then
        -- Buffs
        for i = 1, 16 do
            --local buffI = GetPlayerBuff( i, "HELPFUL" )
			-- name, rank, icon, count, debuffType, duration, expirationTime, isMine, isStealable = UnitAura("unit", [index] or ["name", "rank"][, "filter"]) 
			local name, _, texture, _, _, duration, expirationTime, isMine = UnitAura("player", i, "HELPFUL")
            if name then
				if (duration < 1800) or ( duration >= 1800 and p.pBuffsFilter) then
					local currentTime = GetTime()
					local timeLeft = expirationTime - currentTime
					DHUD2:Debug("updatePlayerAuras", name, timeLeft, timeFilter)
	                if timeLeft > 0 and timeLeft <= timeFilter then
	                    local r, g, b, hex = self:colorize("player", 8, timeLeft / 20)
	                    local button = _G["DHUD2_"..side.."buff"..j]
						button.id = i
	                    button.hasbuff = true
	                    button.hasweapon = false
	                    button.auraTimer = 0
	                    button.left = timeLeft
	                    button:SetNormalTexture(texture)
	                    local buffBorder = _G["DHUD2_"..side.."buff"..j.."_Border"]
	                    buffBorder:SetVertexColor(r, g, b)
	                    buffBorder:Show()
	                    local buffText = _G["DHUD2_"..side.."buff"..j.."_Text"]
	                    buffText:SetText("|cff"..hex..formatTime(button.left))
	                    local w = buffText:GetStringWidth() + 10
	                    buffText:SetWidth(w)
	                    button:SetScript("OnUpdate", self.OnUpdateAura)
	                    button:EnableMouse(true)
	                    button:Show()
	                    if j == 16 then
	                        self:Print("You have reached the buff limit. Contact Arcanefoam and ask for more buff slots")
	                        break
	                    else
	                        j = j + 1
	                    end
	                elseif timeLeft > 0 then
	                    local newtimeToEvent = timeLeft - timeFilter
						if newtimeToEvent < timeToEvent or timeToEvent == 0 then
							timeToEvent = newtimeToEvent
						end
						DHUD2:Debug("updatePlayerAuras",timeToEvent)
	                end
				end
            end
        end
        -- Weapons
        local hasMainHandEnchant, mainHandExpiration, _, hasOffHandEnchant, offHandExpiration, _ = GetWeaponEnchantInfo()
        local id = 0
        local slot = 0
        for i = 1, 2 do
            -- Fit main and off hand
            if i == 1 and hasMainHandEnchant then
                timeLeft = mainHandExpiration/1000
                id = 1
                slot = 16
            elseif i == 2 and hasOffHandEnchant then
                timeLeft = offHandExpiration/1000
                id = 2
                slot = 17
            else
               timeLeft = 0 
            end
            if timeLeft > 0 and timeLeft <= timerFilter then
                timeLeft = math_ceil(timeLeft)
                local r, g, b, hex = self:colorize("player", "aura", timeLeft / 20)
                local button = _G["DHUD2_"..side.."buff"..j]
                button.hasbuff = false
                button.hasweapon = true
				button.duration = timeLeft
                button.auraTimer = 0
                button.id = id
                button:SetNormalTexture(GetInventoryItemTexture("player", slot))
                local buffBorder = _G["DHUD2_"..side.."buff"..j.."_Border"]
                buffBorder:SetVertexColor(r, g, b)
                buffBorder:Show()
                local buffText = _G["DHUD2_"..side.."buff".."_Text"]
                buffText:SetText("|cff"..hex..formatTime(timeLeft))
                button:SetScript("OnUpdate", self.OnUpdateAura)
                button:EnableMouse(true)
                button:Show()
                if j == 16 then
                    self:Print("You have reached the buff limit. Contact Arcanefoam and ask for more buff slots")
                    break
                else
                    j = j + 1
                end
            elseif timeLeft > 0 then
                if timeLeft - timerFilter < timeToEvent then
                    timeToEvent = timeLeft - timerFilter
                end
            end
        end
    end
    for i = j, 16 do
        local button = _G["DHUD2_"..side.."buff"..i]
        button.id = 0
        button.hasbuff = false
        button.hasweapon = false
        button:SetScript("OnUpdate", nil)
        button:EnableMouse(false)
        button:Hide()
    end
    if timeToEvent ~= 0 then
        -- Trigger an event for the buff with closest time to playerBuffTimeFilter
		local handle = self:ScheduleTimer(DHUD2.PLAYER_AURAS_CHANGED, timeToEvent-1)
		DHUD2:Debug("Aura Timer Schedulaed", handle)
    end
end

function DHUD2:hidePlayerBuffs()
	for i = 1, 16 do
		 _G["DHUD2_lbuff"..i]:Hide()
		 _G["DHUD2_rbuff"..i]:Hide()
	end
end
    
function DHUD2:updateTargetAuras(show, swap, showClass, side, warrior, druid)
	DHUD2:Debug("updateTargetAuras", show, swap, showClass, side, warrior, druid)
    local i
    local buffBorder, buffText, buffFrame
    local debuffBorder, debuffText, debuffFrame
    local p = DHUD2.db.profile
	
	if not swap then
		buffFrame   = "DHUD2_TRA";
		debuffFrame = "DHUD2_TLA";
	else
		buffFrame   = "DHUD2_TLA";    
		debuffFrame = "DHUD2_TRA";
	end

	-- Buffs
	for i = 1, 40 do
		local button = _G[buffFrame..i]
		--local buffName, _, buffTexture, buffApplication = UnitBuff("target", i)
		-- name, rank, icon, count, debuffType, duration, expirationTime, isMine, isStealable = UnitAura("unit", [index] or ["name", "rank"][, "filter"])   
		local name, _, texture, count, _, _, _, isMine = UnitAura("target", i, "HELPFUL")
		if show and name then
			--DHUD2:Debug("Buff", i, name, texture, count, isMIne)
			button.hasbuff = true
			button.unit = "target"
			button.id = i
			button:SetNormalTexture(texture)
			buffBorder = _G[buffFrame..i.."_Border"]
			buffBorder:Hide()
			buffText = _G[buffFrame..i.."_Text"]
			if count <= 1 then
				buffText:SetText("")
			elseif count > 1 then
				buffText:SetText(count)
			end
			button:Show()
		else    
			button:Hide()
			button.hasdebuff = false
		end
	end        

	local countClass = 0
	local butTex
	
	-- DeBuffs
	for i = 1, 40 do
		local button = _G[debuffFrame..i]
		--local debuffName, _, debuffTexture, debuffApplication = UnitDebuff("target", i)
		local name, _, texture, count, _, _, _, isMine = UnitAura("target", i, "HARMFUL")
		if show and name then
			--DHUD2:Debug("deBuff", i, name, icon, count, isMIne)
			button.hasdebuff = true
			button.unit = "target"
			button.id = i
			button:SetNormalTexture(texture)
			debuffBorder = _G[debuffFrame..i.."_Border"]
			debuffBorder:Show()
			debuffText = _G[debuffFrame..i.."_Text"]
			if count <= 1 then
				debuffText:SetText("")
			elseif count > 1 then
				debuffText:SetText(count)
			end
			button:Show()
		else
			button:Hide()
			button.hasdebuff = false
		end
		if showClass and name then
			if ( warrior and string_match(name, "Sunder Armor") ) or ( druid and string_match(name, "Lacerate") ) and isMine then
				self:Debug("Class", count)
				countClass = count or 0
				butTex = warrior and "s" or "l"
			end
		end
	end
	if countClass > 0 then
		self:updateButtons(butTex, countClass, side, showClass)
	end
end

function DHUD2:updateTargetIcon(show)    
    local p = DHUD2.db.profile
    if show then
        local _, _, _, _, _, _, _, x0, x1, y0, y1, path = unpack(self.layout.icons.target)
        if UnitIsPVPFreeForAll("target")  then
            path = path[3]
        elseif UnitIsPVP("target") then 
            local faction = UnitFactionGroup("target")
            if faction == "Horde" then
                path = path[2]           
            else
                path = path[1]                
            end
        else
            local index = GetRaidTargetIndex("target")
            if index then
                if index > 0 and index <= 8 then
                    path, x0, x1, y0, y1 = unpack( self.layout.raidIcons[index] )
                end
            end
        end
        _G["DHUD2_target_Texture"]:SetTexture(path)
        _G["DHUD2_target_Texture"]:SetTexCoord(x0,x1,y0,y1)
        _G["DHUD2_target"]:Show()
    else
        _G["DHUD2_target"]:Hide()
    end
end

function DHUD2:updatePetIcon(bar, health, happiness)
    local p = DHUD2.db.profile
    --self:Debug("updatePetIcon", health, happiness)
    if health > 0 and happiness then
        local _, texture, x0, x1, y0, y1 = unpack( self.layout.images.pet[happiness] )
        if texture then
            local tex = _G["DHUD2_"..bar.."pet_Texture"]
            tex:SetTexture(texture)
            tex:SetTexCoord(x0, x1, y0, y1)
            _G["DHUD2_"..bar.."pet"]:Show()
        else
            _G["DHUD2_"..bar.."pet"]:Hide()
        end
    else
        _G["DHUD2_"..bar.."pet"]:Hide()
    end
end
    
function DHUD2:OnUpdateAura(elapsed)
    this.auraTimer = this.auraTimer + elapsed
    if this:GetEffectiveAlpha() == 0 then
        this:EnableMouse(false)
    else            
        this:EnableMouse(true)
        if this.auraTimer >= auraUpdateInterval then
            if this.hasbuff then 
                this.left = this.left - this.auraTimer
            elseif this.hasweapon then
                local _, mainHandExpiration, _, _, offHandExpiration, _ = GetWeaponEnchantInfo()
                if this.id == 1 and mainHandExpiration then 
                    timeLeft = mainHandExpiration/1000
                elseif this.id == 2 and offHandExpiration then
                    timeLeft = offHandExpiration/1000
                end
                if timeLeft == 0 then
                    this:SetScript("OnUpdate", nil)
                    return this:Hide()
                end
            end
			this.auraTimer = 0
            local r, g, b, hex = DHUD2:colorize("player", 8, this.left / 20)
            local buffBorder = _G[this:GetName().."_Border"]
            buffBorder:SetVertexColor(r, g, b)
            local buffText = _G[this:GetName().."_Text"]
			DHUD2:Debug("OnUpdateAura left", this.left, formatTime(this.left))
            buffText:SetText("|cff"..hex..formatTime(this.left))
            local w = buffText:GetStringWidth() + 10
            buffText:SetWidth(w)
            if ( GameTooltip:IsOwned(this) ) then
				GameTooltip:SetUnitAura("player", this.id, "HELPFUL") 
        	end
        end
    end
end

function DHUD2:updateTargetElite(side, show)
    if self:checkElite("target") and show then
        --local images = self.layout.icons
        --local _, _, _, _, _, _, _, _, _, _, _, texture = unpack(images.targetElite)
        --_G["DHUD2_targetElite_Texture:SetTexture(texture)
        _G["DHUD2_"..side.."telite"]:Show()
    else
        _G["DHUD2_"..side.."telite"]:Hide()
    end
end

function DHUD2:updateTotemButton(button, startTime, duration, icon)    
    DHUD2:Debug("updateTotemButton", button)
    local but = _G["DHUD2_"..button]
    local butBorder = _G["DHUD2_"..button.."_Border"]
    local butText = _G["DHUD2_"..button.."_Text"]
	if ( duration > 0 ) then
        duration = math_ceil(duration)
		but:SetNormalTexture(icon)
        local r, g, b, hex = self:colorize("player", 8, duration / 20)
        butBorder:SetVertexColor(r, g, b)
        butBorder:Show()
        butText:SetText("|cff"..hex..formatTime(duration))
        butText:Show()
        but:SetScript("OnUpdate", self.OnUpdateTotem)
        but:EnableMouse(true)
        but:Show()
        --CooldownFrame_SetTimer(buttonCooldown, startTime, duration, 1);
		--buttonCooldown:Show();
	else
		butText:Hide()
		but:SetScript("OnUpdate", nil)
		but:Hide()
	end
end

function DHUD2:OnUpdateTotem(elapsed)
    this.totemTimer = this.totemTimer + elapsed
    if this:GetEffectiveAlpha() == 0 then
        this:EnableMouse(false)
    else            
        this:EnableMouse(true)
        if this.totemTimer >= auraUpdateInterval then
            this.totemTimer = 0
            local timeLeft = math_ceil(GetTotemTimeLeft(this.slot))
            local r, g, b, hex = DHUD2:colorize("player", 8, timeLeft / 20)
            local buffBorder = _G[this:GetName().."_Border"]
            buffBorder:SetVertexColor(r, g, b)
            local buffText = _G[this:GetName().."_Text"]
            buffText:SetText("|cff"..hex..formatTime(timeLeft))
        	if ( GameTooltip:IsOwned(this) ) then
        		GameTooltip:SetTotem(this.slot)
        	end
        end
    end
end
