--[[
Drathals HUD2  - DHUD2
Copyright (c) 2006 by Markus Inger, 2006 by Caeryn Dryad, 2007-2008 by Horacio Hoyos

This file is part of DHUD2.

    DHUD2 is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DHUD2 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DHUD2.  If not, see <http://www.gnu.org/licenses/>.
]]

--Options
local L = LibStub("AceLocale-3.0"):GetLocale("DHUD2")
local options
local string_match = string.match


--Profile Defaults
local classColors = {
    ["HUNTER"] = "ABD473", 
    ["WARLOCK"] = "9482C9",
    ["PRIEST"] = "FFFFFF",
    ["PALADIN"] = "F58CBA",
    ["MAGE"] = "69CCF0",
    ["ROGUE"] = "FFF569",
    ["DRUID"] = "FF7D0A",
    ["SHAMAN"] = "00DBBA",
    ["WARRIOR"] = "C79C6E",
}

local defaults = {
	profile = {
		player = "c",
		pet = "c",
		borders = true,
		scale = 1,
		leftBar = "TTH",
		rightBar = "FH",
		combatAlpha = 1,
		oocAlpha = 0.1,
		selectAlpha = 0.6,
		regenAlpha = 0.4,
		castingAlpha = 0.8,
		deadAlpha = 0,
		blizCasting = false,
		blizPet = false,
		blizPlayer = false,
		blizTarget = false,
		pLayout = "HLPR",
		tLayout = "HLPR",
		pDruid = true,
		pDruSide = "l",
		pDruidText = true,
		pDStyle = "[FractionalDruidMP] ([PercentDruidMP:Percent])",
		pCDStyle = "",
		pDruidTextSize = 10,
		pDruidTextOut = true,
		class = true,
		combatIcon = true,
		pvpIcon = true,
		restIcon= true,
		leaderIcon = true,
		lootIcon = true,
		pBuffs = true,
		pBuffsSide = "r",
		pBuffsExpMin = 0,
		pBuffsExpSec = 60,
		pBuffsFilter = true,
		pBuffsTips = true,
		pBuffsSize = 10,
		pBuffsOut = true,
		pBarHText = true,
		pBarPText = true,
		pHStyle = "[FractionalHP] ([PercentMP:Percent])",
		pCHStyle = "",
		pPStyle = "[FractionalMP] ([PercentMP:Percent])",
		pCPStyle = "",
		pBarTextSize = 10,
		pBarTextOut = true,
		pColors = {
	        ["0"] = {
	            full = { 0, 1, 1 },
	            med = { 0, 0, 1 },
	            low = { 1, 0, 1 }
	        },
	        ["1"] = {
	            full = { 1, 0, 0 },
	            med = { 1, 0.23, 0.23 },
	            low = { 1, 0.42, 0.42 }
	        },
	        ["3"] = { 
	            full = { 1, 1, 0 },
	            med = { 1, 1, 0.23 },
	            low = { 1, 1, 0.42 }
	        },
			["6"] = { 
	            full = { 0, 0.68, 0.87 },
	            med = { 0.23, 0.71, 0.84 },
	            low = { 0.47, 0.75, 0.81 }
	        },
			["7"] = {
	            full = { 0, 1, 0 },
	            med = { 1, 1, 0 },
	            low = { 1, 0, 0 }      
	        },
			["8"] = {
	            full = { 1, 1, 1 },
	            med = { 255/255, 125/255, 125/255 },
	            low = { 255/255, 65/255, 0 }      
	        },
		},
		tBars = true,
		tNPC = true,
		tAuras = true,
		tTips = true,
		tSwap = true,
		tot = true,
		tName = true,
		tStyle = "[Level:DifficultyColor] [Classification] [Name:HostileColor] [isPet ? Creature:ClassColor:Bracket ! isPLayer ? Class:ClassColor:Bracket ! Faction:ClassColor:Bracket]",
		tCStyle = "",
		tNSize = 10,
		tNOut = true,
		totName = true,
		totStyle = "[Level:DifficultyColor] [Classification] [Name:HostileColor] [isPet ? Creature:ClassColor:Bracket ! isPLayer ? Class:ClassColor:Bracket ! Faction:ClassColor:Bracket]",
		totCStyle = "",
		totNSize = 10,
		totNOut = true,
		tPvpIcon = true,
		tEliteIcon = true,
		tBarHText = true,
		tBarPText = true,
		tHStyle = "[FractionalHP] ([PercentHP:Percent])",
		tCHStyle = "",
		tPStyle = "[FractionalMP] ([PercentMP:Percent])",
		tCPStyle = "",
		tBarTextSize = 10,
		tBarTextOut = true,
		tColors = {
			["0"] = {
	            full = { 0, 0.67, 0.67 },
	            med = { 0, 0, 0.67 },
	            low = { 0.67, 0, 0.67 }
	        },
			["1"] = { 
	            full = { 0.67, 0, 0 },
	            med = { 0.67, 0.15, 0.15 },
	            low = { 0.67, 0.28, 0.28 }
	        },
			["2"] = {
	            full = { 0.67, 0.27, 0 },
	            med = { 0.67, 0.27, 0 },
	            low = { 0.67, 0.27, 0 }
	        },
	        ["3"] = { 
	            full = { 0.67, 0.67, 0 },
	            med = { 0.67, 0.67, 0.15 },
	            low = { 0.67, 0.67, 0.28 }
	        },
			["6"] = { 
	            full = { 0, 0.43, 0.58 },
	            med = { 0.15, 0.48, 0.56 },
	            low = { 0.21, 0.50, 0.54 }
	        },
	        ["7"] = {
	            full = { 0, 0.67, 0 },
	            med = { 0.67, 0.67, 0 },
	            low = { 0.67, 0, 0 },
	        },
	        ["8"] = {
	            full = { 0.8, 0.8, 0.8 },
	            med = { 0.73, 0.73, 0.73 },
	            low = { 0.67, 0.67, 0.67 }
	        },
		},
		eBars = true,
		eIcon = true,
		eLayout = "HLPR",
		eBarHText = true,
		eBarPText = true,
		eHStyle = "[FractionalHP] ([PercentHP:Percent])",
		eCHStyle = "",
		ePStyle = "[FractionalMP] ([PercentMP:Percent])",
		eCPStyle = "",
		eBarTextSize = 10,
		eBarTextOut = true,
		eColors = {
			["0"] = {
	            full = { 0, 0.67, 0.67 },
	            med = { 0, 0, 0.67 },
	            low = { 0.67, 0, 0.67 }
	        },
			["1"] = { 
	            full = { 0.67, 0, 0 },
	            med = { 0.67, 0.15, 0.15 },
	            low = { 0.67, 0.28, 0.28 }
	        },
			["2"] = {
	            full = { 0.67, 0.27, 0 },
	            med = { 0.67, 0.27, 0 },
	            low = { 0.67, 0.27, 0 }
	        },
	        ["3"] = { 
	            full = { 0.67, 0.67, 0 },
	            med = { 0.67, 0.67, 0.15 },
	            low = { 0.67, 0.67, 0.28 }
	        },
			["6"] = { 
	            full = { 0, 0.43, 0.58 },
	            med = { 0.15, 0.48, 0.56 },
	            low = { 0.21, 0.50, 0.54 }
	        },
	        ["7"] = {
	            full = { 0, 0.67, 0 },
	            med = { 0.67, 0.67, 0 },
	            low = { 0.67, 0, 0 },
	        },
		},
		oBarHText = true,
		oBarPText = true,
		oHStyle = "[FractionalHP] ([PercentHP:Percent])",
		oCHStyle = "",
		oPStyle = "[FractionalMP] ([PercentMP:Percent])",
		oCPStyle = "",
		oBarTextSize = 10,
		oBarTextOut = true,
		oColors = {
			["0"] = {
	            full = { 0, 0.67, 0.67 },
	            med = { 0, 0, 0.67 },
	            low = { 0.67, 0, 0.67 }
	        },
			["1"] = { 
	            full = { 0.67, 0, 0 },
	            med = { 0.67, 0.15, 0.15 },
	            low = { 0.67, 0.28, 0.28 }
	        },
			["2"] = {
	            full = { 0.67, 0.27, 0 },
	            med = { 0.67, 0.27, 0 },
	            low = { 0.67, 0.27, 0 }
	        },
	        ["3"] = { 
	            full = { 0.67, 0.67, 0 },
	            med = { 0.67, 0.67, 0.15 },
	            low = { 0.67, 0.67, 0.28 }
	        },
			["6"] = { 
	            full = { 0, 0.43, 0.58 },
	            med = { 0.15, 0.48, 0.56 },
	            low = { 0.21, 0.50, 0.54 }
	        },
	        ["7"] = {
	            full = { 0, 0.67, 0 },
	            med = { 0.67, 0.67, 0 },
	            low = { 0.67, 0, 0 },
	        },
	        ["8"] = {
	            full = { 0.8, 0.8, 0.8 },
	            med = { 0.73, 0.73, 0.73 },
	            low = { 0.67, 0.67, 0.67 },
	        },
		},
		pCast = true,
		pRev = false,
		pTime = true,
		pDelay = true,
		pSpell = true,
		pCastSize = 10,
		pCastOut = true,
		tCast = true,
		tRev = false,
		tTime = true,
		tDelay = true,
		tSpell = true,
		tCastSize = 10,
		tCastOut = true,
		castColors = {
	        cast = { 
	            full = { 0, 1, 0 },
	            med = { 0.53, 1, 0 },
	            low = { 1, 1, 0 },
	        },
	        channel = { 
	            full = { 0.88, 0.88, 1 },
	            med = { 0.75, 0.75, 0 },
	            low = { 0.63, 0.63, 0 },
	        },
		},
	}
}

function DHUD2:getBarColor(self, info)
	DHUD2:Print(tostring(self), tostring(info))
	return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
end

function DHUD2:setBarColor(self, info, r, g, b)
	DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
	DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
	DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
end

do

    local layoutType = {["c"] = L["Centered"], ["r"] = L["Right"], ["l"] = L["Left"]}
	--Styles
    local healthTags = {
		["[FractionalHP] ([PercentHP:Percent])"] = "Current/Max (Percent%)",
		["[FractionalHP]"] = "Current/Max",
		["[HP] ([PercentHP:Percent])"] = "Current (Percent%)",
		["[PercentHP:Percent]"] = "Percent%",
		["[HP]"] = "Current"
	}
	local powerTags = {
		["[FractionalMP] ([PercentMP:Percent])"] = "Current/Max (Percent%)",
		["[FractionalMP]"] = "Current/Max",
		["[MP] ([PercentMP:Percent])"] = "Current (Percent%)",
		["[PercentMP:Percent]"] = "Percent%", 
		["[MP]"] = "Current"
	}
	local nameTags = {
	    ["[Level:DifficultyColor] [Classification] [Name:HostileColor] [isPet ? Creature:ClassColor:Bracket ! isPLayer ? Class:ClassColor:Bracket ! Faction:ClassColor:Bracket"] = "<level><elite> <name> [ <class> ]",
	    ["[Level:DifficultyColor] [Classification] [Name:HostileColor]"] = "<level><elite> <name>",
	    ["[Name:HostileColor] [isPet ? Creature:ClassColor:Bracket ! isPLayer ? Class:ClassColor:Bracket ! Faction:ClassColor:Bracket"] = "<name> [ <class> ]",
	    ["[Level:DifficultyColor] [Name:HostileColor]"] = "<level> <name>",
    }
	local druidTags = {
		["[FractionalDruidMP] ([PercentDruidMP:Percent])"] = "Current/Max (Percent%)",
		["[FractionalDruidMP]"] = "Current/Max",
		["[DruidMP] ([PercentDruidMP:Percent])"] = "Current (Percent%)",
		["[PercentDruidMP:Percent]"] = "Percent%",
		["[DruidMP]"] = "Current"
	}
	-- Outer Bars
    local outerVal = {
        ["TTH"] = L["TargetTarget Health"],
        ["TTP"] = L["TargetTarget Power"],
        ["FH"] = L["Focus Health"],
        ["FP"] = L["Focus Power"],
        [""] = L["None"]
    }
	--Fonts
    local maxfont = 30
    local minfont = 6
	
    --Options table
	options = {
		type = 'group',
		dialogInline = true,
		args = {
            layout = {
                type = 'group',
				order = 1,
                name = L["Layout"],
                desc = L["Configure DHUD2 general layout options"],
                args = {
                    player = {
                        type = 'select',
						order = 1,
                        name = L["Player/Target Bars"],
                        desc = L["Place the Player's bars. Target's bars will be set accordingly"],
                        get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
                        set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								if string_match(value, "c") then
					                DHUD2.db.profile.pLayout = "HLPR"
									DHUD2.db.profile.tLayout = "HLPR"
					            else
					                DHUD2.db.profile.pLayout = "HIPM"
									DHUD2.db.profile.tLayout = "HIPM"
					            end
								DHUD2:setup()
							end,
                        values = layoutType,
                    },                    
					borders = {
                        type = 'toggle',
						order = 3,
                        name = L["Bar Borders"],
                        desc = L["Show bar borders"],
                        get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
                        set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
							end,
                    },
					scale = {
                        type = 'range',
						order = 4,
                        name = L["Set DHUD2's scale"],
                        min = 0.2,
                        max = 2,
                        step = 0.1,
                        get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
                        set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
							end,
                    },
                    outer= {
                        type = 'group',
						order = 7,
                        name = L["Outer Bars"],
                        desc = L["Choose what to track on the Outer Bars"],
                        args = {
                            leftBar = {
                                type = 'select',
                                name = L["Left bar display"],
                                get = getVal,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = outerVal,
                            },
                            rightBar = {
                                type = 'select',
                                name = L["Right bar display"],
                                get = getVal,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = outerVal,
                            },
                        },
                    },
                    alphas = {
                        type = 'group',
						order = 6,
                        name = L["Alphas"],
                        desc = L["Set HUD situation alpha"],
                        args = {
                            combatAlpha = {
                                type = 'range',
                                name = L["Combat"],
                                min = 0,
                                max = 1,
                                step = 0.05,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:updateAlpha()
									end,
                            },
                            oocAlpha = {
                                type = 'range',
                                name = L["Off Combat"],
                                min = 0,
                                max = 1,
                                step = 0.05,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:updateAlpha()
									end,
                            },
                            selectAlpha = {
                                type = 'range',
                                name = L["Selection"],
                                min = 0,
                                max = 1,
                                step = 0.05,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:updateAlpha()
									end,
                            },
                            regenAlpha = {
                                type = 'range',
                                name = L["Regeneration"],
                                min = 0,
                                max = 1,
                                step = 0.05,
		                        get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:updateAlpha()
									end,
                            },
                            deadAlpha = {
                                type = 'range',
                                name = L["Death"],
                                min = 0,
                                max = 1,
                                step = 0.05,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:updateAlpha()
									end,
                            },
                        },
                    },
                    show = {
                        type = 'group',
						order = 5,
						inline = true,
                        name = L["Show Bliz Frames"],
                        desc = L["Show/Hide bliz frames"],
                        args = {
                            blizCasting = {
                                type ='toggle',
                                name = L["Casting Bar"],
                                desc = L["Show Blizzard casting bar"],
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
                            blizPet = {
                                type ='toggle',
                                name = L["Pet Frame"],
                                desc = L["Show Blizzard's pet frame"],
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
                            blizPlayer = {
                                type ='toggle',
                                name = L["Player Frame"],
                                desc = L["Show Blizzard's player frame"],
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
                            blizTarget = {
                                type ='toggle',
                                name = L["Target Frame"],
                                desc = L["Show Blizzard's target frame"],
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
                        },
                    },
                },
            },
            player = {
                type = 'group',
				order = 2,
                name = L["Player"],
                desc = L["Configure the player's layout options"],
                args = {    
                    pLayout = {
						type = 'select',
						order = 1,
						name = L["Bar Layout"],
						get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
                        set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								DHUD2:setup()
							end,
						values = function ()
								if string_match(DHUD2.db.profile.player, "c") then
									return { ["HLPR"] = L["Health Left/Power Right"], ["HRPL"] = L["Health Right/Power Left"] }
								else
									return { ["HIPM"] = L["Health Inner/Power Outter"], ["HMPI"] = L["Health Outter/Power Inner"] }
								end
							end,
					},
					druid = {
						type = 'group',
						order = 2,
						name = L["Druid Bar"],
						desc = L["By using SmartyCat or DruidBar you can use the outer Pet Bar to display Druid's Mana value while shape-shifted"],
						hidden = function()
								return not DHUD2.isDruid
							end,
						args = {
							pDruid = {
								type ='toggle',
								name = L["Show"],
								order = 1,
								desc = L["Show mana bar when shape-shifted"],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								},
							pDruSide = {
								type = 'select',
								name = L["Side"],
								order = 2,
								hidden = function ()
										return not DHUD2.db.profile.pDruid
									end,
								desc = L["Choose druid mana bar side"],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = {["r"] = L["Right side"], ["l"] = L["Left side"]},
							},
							barText = {
								type = 'group',
								inline = true,
								order = 3,
								hidden = function ()
										return not DHUD2.db.profile.pDruid
									end,
								name = L["Bar's Text"],
		                        desc = L["Configure Druid Mana text options"],
								args = {
									pDruidText = {
										type = 'toggle',
										order = 1,
										name = L["Show Bar Values"],
										get = function (info)
												return DHUD2.db.profile[info[#info]]
											end,
										set = function (info, value)
												DHUD2.db.profile[info[#info]] = value
												DHUD2:setup()
											end,
									},
									pDStyle = {
										type = 'select',
										order = 2,
										name = L["Text Style"],
										hidden = function ()
												return not DHUD2.db.profile.pDruidText
											end,
										get = function (info)
												return DHUD2.db.profile[info[#info]]
											end,
				                        set = function (info, value) 
												DHUD2.db.profile[info[#info]] = value
												DHUD2:setup()
											end,
										values = druidTags
										},
									pCDStyle = {
										type = 'input',
										order = 3,
										name = L["Custom Style"],
										desc = L["If set this style will override Text Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
										hidden = function ()
												return not DHUD2.db.profile.pDruidText
											end,
										usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
										get = function (info)
												return DHUD2.db.profile[info[#info]]
											end,
				                        set = function (info, value) 
												DHUD2.db.profile[info[#info]] = value
												DHUD2:setup()
											end,								
									},
									pDruidTextSize = {
				                        type = 'range',
										order = 6,
				                        name = L["Font size"],
										hidden = function ()
												return not DHUD2.db.profile.pDruidText 
											end,
				                        min = minfont,
				                        max = maxfont,
				                        step = 1,
				                        get = function (info)
												return DHUD2.db.profile[info[#info]]
											end,
				                        set = function (info, value) 
												DHUD2.db.profile[info[#info]] = value
												DHUD2:setup()
											end,
				                        },
								},
							},	
						},
					},
					class = {
                        type = 'toggle',
						order = 3,
                        name = L["Class Abilities"],
                        desc = L["Show specific class abilities: combos, totems, sunders, lacerates or runes."],
                        get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
						set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								DHUD2:setup()
							end,
                    },
					icons = {
                        type = 'multiselect',
						order = 4,
                        name = L["Status Icons"],
						get = function (info, select)
								return DHUD2.db.profile[select]
							end,
						set = function (info, select, value) 
								DHUD2.db.profile[select] = value
								DHUD2:setup()
							end,
                        values = { ["combatIcon"] = L["In Combat"],
								   ["pvpIcon"] = L["PVP Flaged"],
								   ["restIcon"] = L["Resting"],
								   ["leaderIcon"] = L["Party Leader"],
								   ["lootIcon"] = L["Master Looter"] },
                    },
                    buffs = {
                        type = 'group',
						order = 5,
                        name = L["Buffs Setup"],
                        args = {
                            pBuffs = {
                                type ='toggle',
								order = 1,
                                name = L["Enable Buff Tracking"],
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
							pBuffsSide = {
                                type = 'select',
								order = 2,
                                name = L["Side"],
                                desc = L["Select side to show buffs"],
								hidden = function ()
										return not DHUD2.db.profile.pBuffs
									end,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                                values = { ["r"] = L["Right side"], ["l"] = L["Left side"] },
                            },
							expiration = {
								type = 'group',
								order = 3,
								inline = true,
								name = L["Expiration"],
								desc = L["Time before buff expiration to show it"],
								hidden = function ()
										return not DHUD2.db.profile.pBuffs
									end,
								childGroups = "tab",
								args = {
									pBuffsExpMin = {
										type = 'range',
										name = L["Minutes"],
										min = 0,
										max = 60,
										step = 1,
										get = function (info)
												return DHUD2.db.profile[info[#info]]
											end,
				                        set = function (info, value) 
												DHUD2.db.profile[info[#info]] = value
												DHUD2:setup()
											end,
									},
									pBuffsExpSec = {
										type = 'range',
										name = L["Seconds"],
										min = 0,
										max = 60,
										step = 1,
										get = function (info)
												return DHUD2.db.profile[info[#info]]
											end,
				                        set = function (info, value) 
												DHUD2.db.profile[info[#info]] = value
												DHUD2:setup()
											end,
									},
								},
							},
							pBuffsFilter = {
								type = 'toggle',
								order = 4,
								name = L["Long Buffs"],
								desc = L["Track buffs longer than 30 minutes"],
								hidden = function ()
										return not DHUD2.db.profile.pBuffs
									end,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
							},
                            pBuffsTips = {
                                type ='toggle',
								order = 5,
								name = L["Tips"],
                                desc = L["Show aura tips when moused over"],
								hidden = function ()
										return not DHUD2.db.profile.pBuffs
									end,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
							text = {
								type = 'group',
								inline = true,
								order = 6,
								name = L["Font"],
								hidden = function ()
										return not DHUD2.db.profile.pBuffs
									end,
								args = {
									pBuffsSize = {
				                        type = 'range',
										order = 1,
										name = L["Size"],
				                        min = minfont,
				                        max = maxfont,
				                        step = 1,
				                        get = function (info)
												return DHUD2.db.profile[info[#info]]
											end,
				                        set = function (info, value) 
												DHUD2.db.profile[info[#info]] = value
												DHUD2:setup()
											end,
				                    },
								},
							},
							pColors = {
								type = 'group',
								inline = true,
								order = 7,
                                name = L["Color"],
								name = L["Border Color"],
								hidden = function ()
										return not DHUD2.db.profile.pBuffs
									end,
								args = {
									full = {
										type = 'color',
										order = 1,
										name = L["Full"],
										get = function (info)
												return DHUD2.db.profile[info[#info-1]]["8"][info[#info]][1], DHUD2.db.profile[info[#info-1]]["8"][info[#info]][2], DHUD2.db.profile[info[#info-1]]["8"][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-1]]["8"][info[#info]][1] = r
												DHUD2.db.profile[info[#info-1]]["8"][info[#info]][2] = g
												DHUD2.db.profile[info[#info-1]]["8"][info[#info]][3] = b
                                                DHUD2:setup()
											end,
									},
									med = {
										type = 'color',
										order = 2,
										name = L["Med"],
										get = function (info)
												return DHUD2.db.profile[info[#info-1]]["8"][info[#info]][1], DHUD2.db.profile[info[#info-1]]["8"][info[#info]][2], DHUD2.db.profile[info[#info-1]]["8"][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-1]]["8"][info[#info]][1] = r
												DHUD2.db.profile[info[#info-1]]["8"][info[#info]][2] = g
												DHUD2.db.profile[info[#info-1]]["8"][info[#info]][3] = b
                                                DHUD2:setup()
											end,
									},
									low = {
										type = 'color',
										order = 3,
										name = L["Low"],
										get = function (info)
												return DHUD2.db.profile[info[#info-1]]["8"][info[#info]][1], DHUD2.db.profile[info[#info-1]]["8"][info[#info]][2], DHUD2.db.profile[info[#info-1]]["8"][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-1]]["8"][info[#info]][1] = r
												DHUD2.db.profile[info[#info-1]]["8"][info[#info]][2] = g
												DHUD2.db.profile[info[#info-1]]["8"][info[#info]][3] = b
                                                DHUD2:setup()
											end,
									},
								},
							},       
                        },
                    },
                    barText = {
						type = 'group',
						order = 6,
						name = L["Bar's Text"],
                        desc = L["Configure Health and Power (mana/rage/energy/runic) text options"],
						args = {
							pBarText = {
								type = 'multiselect',
								order = 1,
								name = L["Show Bar Values"],
								get = function (info, select)
										return DHUD2.db.profile[select]
									end,
								set = function (info, select, value) 
										DHUD2.db.profile[select] = value
										DHUD2:setup()
									end,
								values = { ["pBarHText"] = L["Health"], ["pBarPText"] = L["Power"] }, 
							},
							pHStyle = {
								type = 'select',
								order = 2,
								name = L["Health Style"],
								hidden = function ()
										return not DHUD2.db.profile.pBarHText
									end,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = healthTags
								},
							pCHStyle = {
								type = 'input',
								order = 3,
								name = L["Custom Health Style"],
								desc = L["If set this style will override Health Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
								hidden = function ()
										return not DHUD2.db.profile.pBarHText
									end,
								usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,								
							},
							pPStyle = {
								type = 'select',
								order = 4,
								name = L["Power Style"],
								hidden = function ()
										return not DHUD2.db.profile.pBarPText
									end,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = powerTags
								},
							pCPStyle = {
								type = 'input',
								order = 5,
								name = L["Custom Power Style"],
								desc = L["If set this style will override Health Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
								hidden = function ()
										return not DHUD2.db.profile.pBarPText
									end,
								usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,								
							},
							pBarTextSize = {
		                        type = 'range',
								order = 6,
		                        name = L["Font size"],
								hidden = function ()
										return not (DHUD2.db.profile.pBarHText or DHUD2.db.profile.pBarPText) 
									end,
		                        min = minfont,
		                        max = maxfont,
		                        step = 1,
		                        get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
		                        },
						},
					},	
                    pColors = {
						type = 'group',
						order = 2700,
						name = L["Bar Colors"],
						args = {
		                    ["7"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Health"],
								order = 1,
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["0"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Mana"],
								args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["1"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Rage"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["3"] = { 
		                        type = 'group',
								inline = true,
		                        name = L["Energy"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
							["6"] = { 
		                        type = 'group',
								inline = true,
		                        name = L["Runic Power"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
		                },
					},
				},
            },
            target = {
                type = 'group',
				order = 3,	
                name = L["Target"],
                desc = L["Configure the target's layout options"],
                args = {
                    options = {
                        type = 'multiselect',
						order = 1,
                        name = L["Show"],
                        desc = L["Set the display options when targeting"],
						get = function (info, select)
								return DHUD2.db.profile[select]
							end,
						set = function (info, select, value) 
								DHUD2.db.profile[select] = value
								DHUD2:setup()
							end,
                        values = { ["tBars"] = L["Target Bars"],
								   ["tNPC"] = L["When NPC"],
								   ["tAuras"] = L["Target Auras"],
								   ["tSwap"] = L["Swap Target Auras"] },
                    },
                    tName = {
                        type = 'group',
						order = 2,
                        name = L["Target Name Plate"],
						hidden = function ()
								return not DHUD2.db.profile.tBars
							end,
                        args = {
							tName = {
								type = 'toggle',
								order = 1,
								name = L["Show"],
								desc = L["Show target Name plate"],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
								set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
							},
							tStyle = {
								type = 'select',
								order = 2,
								name = L["Name Style"],
								hidden = function ()
										return not DHUD2.db.profile.tName
									end,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = nameTags
							},
							tCStyle = {
								type = 'input',
								order = 3,
								name = L["Custom Name Style"],
								desc = L["If set this style will override Name Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
								hidden = function ()
										return not DHUD2.db.profile.tName
									end,
								usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,								
							},
                            tNSize = {
                                type = 'range',
								order = 4,
                                name = L["Size"],
								hidden = function ()
										return not DHUD2.db.profile.tName
									end,
                                min = minfont,
                                max = maxfont,
                                step = 1,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
                        },
                    },
                    totName = {
                        type = 'group',
						order = 3,
                        name = L["Target Target Name Plate"],
						hidden = function ()
								return not DHUD2.db.profile.tot
							end,
                        args = {
							totName = {
								type = 'toggle',
								order = 1,
								name = L["Show"],
								desc = L["Show target of target Name plate"],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
								set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
							},
							totStyle = {
								type = 'select',
								order = 2,
								name = L["Name Style"],
								hidden = function ()
										return not DHUD2.db.profile.totName
									end,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = nameTags
							},
							totCStyle = {
								type = 'input',
								order = 3,
								name = L["Custom Name Style"],
								desc = L["If set this style will override Name Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
								hidden = function ()
										return not DHUD2.db.profile.tName
									end,
								usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,								
							},
                            totNSize = {
                                type = 'range',
								order = 4,
                                name = L["Size"],
								hidden = function ()
										return not DHUD2.db.profile.totName
									end,
                                min = minfont,
                                max = maxfont,
                                step = 1,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
                        },
                    },
                    icons = {
                        type = 'multiselect',
						order = 4,
                        name = L["Status Icons"],
						hidden = function ()
								return not DHUD2.db.profile.tBars
							end,
                        values = { ["tPvpIcon"] = L["Show PVP Flag"], ["tEliteIcon"] = L["Show Elite"] },
                        get = function (info, select)
								return DHUD2.db.profile[select]
							end,
						set = function (info, select, value) 
								DHUD2.db.profile[select] = value
								DHUD2:setup()
							end,
                    },
                    barText = {
						type = 'group',
						order = 5,
						name = L["Bar's Text"],
                        desc = L["Configure Health and Power (mana/rage/energy/runic) text options"],
						hidden = function ()
								return not DHUD2.db.profile.tBars
							end,
						args = {
							tBarText = {
								type = 'multiselect',
								order = 1,
								name = L["Show Bar Values"],
								get = function (info, select)
										return DHUD2.db.profile[select]
									end,
								set = function (info, select, value) 
										DHUD2.db.profile[select] = value
										DHUD2:setup()
									end,
								values = { ["tBarHText"] = L["Health"], ["tBarPText"] = L["Power"] }, 
							},
							tHStyle = {
								type = 'select',
								order = 2,
								name = L["Health Style"],
								hidden = function ()
										return not DHUD2.db.profile.tBarHText
									end,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = healthTags
								},
							tCHStyle = {
								type = 'input',
								order = 3,
								name = L["Custom Health Style"],
								desc = L["If set this style will override Health Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
								hidden = function ()
										return not DHUD2.db.profile.tBarHText
									end,
								usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,								
							},
							tPStyle = {
								type = 'select',
								order = 4,
								name = L["Power Style"],
								hidden = function ()
										return not DHUD2.db.profile.tBarPText
									end,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = powerTags
								},
							tCPStyle = {
								type = 'input',
								order = 5,
								name = L["Custom Power Style"],
								desc = L["If set this style will override Health Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
								hidden = function ()
										return not DHUD2.db.profile.tBarPText
									end,
								usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,								
							},
							tBarTextSize = {
		                        type = 'range',
								order = 6,
		                        name = L["Font size"],
								hidden = function ()
										return not (DHUD2.db.profile.tBarHText or DHUD2.db.profile.tBarPText) 
									end,
		                        min = minfont,
		                        max = maxfont,
		                        step = 1,
		                        get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
		                        },
						},
					},	
                    tColors = {
						type = 'group',
						order = 6,
						name = L["Bar Colors"],
						hidden = function ()
								return not DHUD2.db.profile.tBars
							end,
						args = {
		                    ["7"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Health"],
								order = 1,
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["0"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Mana"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["1"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Rage"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["3"] = { 
		                        type = 'group',
								inline = true,
		                        name = L["Energy"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
							["6"] = { 
		                        type = 'group',
								inline = true,
		                        name = L["Runic Power"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
		                    ["2"] = {
                                type = 'group',
								inline = true,
                                name = L["Focus (Pet)"],
                                args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
                            ["8"] = {
                                type = 'group',
								inline = true,
                                name = L["Tapped"],
                                args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
						},
					},
				},
			},
            pet = {
                type = 'group',
				order = 4,
                name = L["Pet"],
                desc = L["Configure the pet's layout options"],
                args = {
					eBars = {
                        type = 'toggle',
						order = 1,
                        name = L["Show Bars"],
                        get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
						set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								DHUD2:setup()
							end,
                    },
					pet = {
                        type = 'select',
                        name = L["Pet Bars"],
						order = 2,
                        desc = L["Place the pet's bars"],
						hidden = function () 
								return not  DHUD2.db.profile.eBars
							end,
                        get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
                        set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								if string_match(value, "c") then
					                DHUD2.db.profile.eLayout = "HLPR"
					            else
					                DHUD2.db.profile.eLayout = "HIPM"
					            end
							end,
                        values = layoutType,
                    },
                    eLayout = {
                        type = 'select',
						order = 3,
                        name = L["Health and Focus"],
						hidden = function ()
								return not DHUD2.db.profile.eBars
							end,
						get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
                        set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								DHUD2:setup()
							end,
                        values = function ()
                                if string_match(DHUD2.db.profile.pet, "c") then
                                    return { ["HLPR"] = L["Health Left/Focus Right"], ["HRPL"] = L["Health Right/Focus Left"] }
                                else
                                    return { ["HIPM"] = L["Health Inner/Focus Outter"], ["HMPI"] = L["Health Outter/Focus Inner"] }
                                end
                            end,
                    },
					eIcon = {
                        type = 'toggle',
						order = 4,
                        name = L["Show Happiness icon"],
                        hidden = function () 
								return not  DHUD2.db.profile.eBars
							end,
                        get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
						set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								DHUD2:setup()
							end,
                    },
                    barText = {
						type = 'group',
						order = 5,
						name = L["Bar's Text"],
                        desc = L["Configure Health and Focus text options"],
						hidden = function ()
								return not DHUD2.db.profile.eBars
							end,
						args = {
							show = {
								type = 'multiselect',
								order = 1,
								name = L["Show Bar Values"],
								get = function (info, select)
										return DHUD2.db.profile[select]
									end,
								set = function (info, select, value) 
										DHUD2.db.profile[select] = value
										DHUD2:setup()
									end,
								values = { ["eBarHText"] = L["Health"], ["eBarPText"] = L["Power"] }, 
							},
							eHStyle = {
								type = 'select',
								order = 2,
								name = L["Health Style"],
								hidden = function ()
										return not DHUD2.db.profile.eBarHText
									end,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = healthTags
								},
							eCHStyle = {
								type = 'input',
								order = 3,
								name = L["Custom Health Style"],
								desc = L["If set this style will override Health Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
								hidden = function ()
										return not DHUD2.db.profile.eBarHText
									end,
								usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,								
							},
							ePStyle = {
								type = 'select',
								order = 4,
								name = L["Power Style"],
								hidden = function ()
										return not DHUD2.db.profile.eBarPText
									end,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
								values = powerTags
								},
							eCPStyle = {
								type = 'input',
								order = 5,
								name = L["Custom Power Style"],
								desc = L["If set this style will override Health Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
								hidden = function ()
										return not DHUD2.db.profile.eBarPText
									end,
								usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,								
							},
							eBarTextSize = {
		                        type = 'range',
								order = 6,
		                        name = L["Font size"],
								hidden = function ()
										return not (DHUD2.db.profile.eBarHText or DHUD2.db.profile.eBarPText) 
									end,
		                        min = minfont,
		                        max = maxfont,
		                        step = 1,
		                        get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
		                        set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
		                    },
						},
					},	
                    eColors = {
						type = 'group',
						order = 6,
						name = L["Bar Colors"],
						hidden = function () 
								return not  DHUD2.db.profile.eBars
							end,
						args = {
		                    ["7"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Health"],
								order = 1,
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["0"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Mana"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["1"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Rage"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["3"] = { 
		                        type = 'group',
								inline = true,
		                        name = L["Energy"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
							["6"] = { 
		                        type = 'group',
								inline = true,
		                        name = L["Runic Power"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
		                    ["2"] = {
                                type = 'group',
								inline = true,
                                name = L["Focus (Pet)"],
                                args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
						},
					},
                },
            },
            Outer= {
                type = 'group',
				order = 5,
                name = L["Outer Bars"],
                desc = L["Configure the Outer Bar's layout options"],
                args = {
					show = {
						type = 'multiselect',
						order = 1,
						name = L["Show Bar Values"],
						get = function (info, select)
								return DHUD2.db.profile[select]
							end,
						set = function (info, select, value) 
								DHUD2.db.profile[select] = value
								DHUD2:setup()
							end,
						values = { ["oBarHText"] = L["Health"], ["oBarPText"] = L["Power"] }, 
					},
					oHStyle = {
						type = 'select',
						order = 2,
						name = L["Health Style"],
						hidden = function ()
								return not DHUD2.db.profile.oBarHText
							end,
						get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
						set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								DHUD2:setup()
							end,
						values = healthTags
						},
					oCHStyle = {
						type = 'input',
						order = 3,
						name = L["Custom Health Style"],
						desc = L["If set this style will override Health Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
						hidden = function ()
								return not DHUD2.db.profile.oBarHText
							end,
						usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
						get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
						set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								DHUD2:setup()
							end,								
					},
					oPStyle = {
						type = 'select',
						order = 4,
						name = L["Power Style"],
						hidden = function ()
								return not DHUD2.db.profile.oBarPText
							end,
						get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
						set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								DHUD2:setup()
							end,
						values = powerTags
						},
					oCPStyle = {
						type = 'input',
						order = 5,
						name = L["Custom Power Style"],
						desc = L["If set this style will override Health Style value. Use LibDogTag-3.o Tags. (Note: Leave/set blank to use Heatlh Style setting.)"],
						hidden = function ()
								return not DHUD2.db.profile.oBarPText
							end,
						usage = L["Enter /dog for in-game LibDogTag-3.0 Tag documentation."],
						get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
						set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								DHUD2:setup()
							end,								
					},
					oBarTextSize = {
						type = 'range',
						order = 6,
						name = L["Font size"],
						hidden = function ()
								return not (DHUD2.db.profile.oBarHText or DHUD2.db.profile.oBarPText) 
							end,
						min = minfont,
						max = maxfont,
						step = 1,
						get = function (info)
								return DHUD2.db.profile[info[#info]]
							end,
						set = function (info, value) 
								DHUD2.db.profile[info[#info]] = value
								DHUD2:setup()
							end,
					},
					oColors = {
						type = 'group',
						order = 6,
						name = L["Bar Colors"],
						hidden = function ()
								return not DHUD2.db.profile.tBars
							end,
						args = {
		                    ["7"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Health"],
								order = 1,
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["0"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Mana"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["1"] = {
		                        type = 'group',
								inline = true,
		                        name = L["Rage"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
		                    ["3"] = { 
		                        type = 'group',
								inline = true,
		                        name = L["Energy"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
		                    },
							["6"] = { 
		                        type = 'group',
								inline = true,
		                        name = L["Runic Power"],
		                        args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
		                    ["2"] = {
                                type = 'group',
								inline = true,
                                name = L["Focus (Pet)"],
                                args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
                            ["8"] = {
                                type = 'group',
								inline = true,
                                name = L["Tapped"],
                                args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
						},
					},
                },
            },
            cast = {
                type = 'group',
				order = 6,
                name = L["Cast Bars Options"],
                desc = L["Configure the Player and Target Cast Bar's layout options"],
                args = {
                    player = {
                        type = 'group',
						order = 1,
                        name = L["Player"],
                        args = {
                            pCast = {
                                type ='toggle',
								order = 1,
                                name = L["Show"],
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
								set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
                            pRev = {
                                type = 'toggle',
								order = 2,
                                name = L["Reverse Cast bar"],
								hidden = function ()
										return not DHUD2.db.profile.pCast
									end,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
								set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
   							value = {
								type = 'multiselect',
								order = 3,
								name = L["Show Bar Values"],
								hidden = function ()
										return not DHUD2.db.profile.pCast
									end,
								get = function (info, select)
										return DHUD2.db.profile[select]
									end,
								set = function (info, select, value) 
										DHUD2.db.profile[select] = value
										DHUD2:setup()
									end,
								values = { ["pTime"] = L["Cast time"], ["pDelay"] = L["Delay time"], ["pSpell"] = L["Spell Name"] }, 
							},
							pCastSize = {
								type = 'range',
								order = 4,
								name = L["Font size"],
								hidden = function ()
										return not DHUD2.db.profile.pCast
									end,
								min = minfont,
								max = maxfont,
								step = 1,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
								set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
							},
                        },
                    },
                    target = {
                        type = 'group',
						order = 2,
                        name = L["Target"],
                        args = {
                            tCast = {
                                type ='toggle',
								order = 1,
                                name = L["Show"],
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
								set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
                            tRev = {
                                type = 'toggle',
								order = 2,
                                name = L["Reverse Cast bar"],
								hidden = function ()
										return not DHUD2.db.profile.tCast
									end,
                                get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
								set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
                            },
   							value = {
								type = 'multiselect',
								order = 3,
								name = L["Show Bar Values"],
								hidden = function ()
										return not DHUD2.db.profile.tCast
									end,
								get = function (info, select)
										return DHUD2.db.profile[select]
									end,
								set = function (info, select, value) 
										DHUD2.db.profile[select] = value
										DHUD2:setup()
									end,
								values = { ["tTime"] = L["Cast time"], ["tDelay"] = L["Delay time"], ["tSpell"] = L["Spell Name"] }, 
							},
							tCastSize = {
								type = 'range',
								order = 4,
								name = L["Font size"],
								hidden = function ()
										return not DHUD2.db.profile.tCast
									end,
								min = minfont,
								max = maxfont,
								step = 1,
								get = function (info)
										return DHUD2.db.profile[info[#info]]
									end,
								set = function (info, value) 
										DHUD2.db.profile[info[#info]] = value
										DHUD2:setup()
									end,
							},
                        },
                    },
                    castColors = {
                        type = 'group',
						order = 3,
                        name = L["Colors"],
                        desc = L["Spell and Channel Spell colors"],
                        args = {
                            cast = { 
                                type = 'group',
								inline = true;
                                name = L["Spell"],
                                args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
                            channel = { 
                                type = 'group',
								inline = true,
                                name = L["Channel"],
                                desc = L["Channel Spell color"],
                                args = {
		                            full = {
		                                type = 'color',
		                                name = L["Full"],
										order = 1,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            med = {
		                                type = 'color',
		                                name = L["Med"],
										order = 2,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                            low = {
		                                type = 'color',
		                                name = L["Low"],
										order = 3,
		                                get = function (info)
												return DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2], DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3]
											end,
				                        set = function (info, r, g, b) 
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][1] = r
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][2] = g
												DHUD2.db.profile[info[#info-2]][info[#info-1]][info[#info]][3] = b
                                                DHUD2:setup()
											end,
		                            },
		                        },
                            },
                        },
                    },
                },
            },
		},
	}

end
DHUD2.options = options
DHUD2.defaults = defaults
